.. nodoctest

d-dimensional Sturmian Configurations
=====================================

.. automodule:: slabbe.ddim_sturmian_configuration
   :members:
   :undoc-members:
   :show-inheritance:
   

